<?php

namespace Drupal\keycrm\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\commerce_product\Entity\ProductInterface;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\Render\RendererInterface;
use Drupal\Core\Entity\EntityViewBuilderInterface;
use Drupal\commerce_product\Entity\Product;
use Drupal\commerce_product\Entity\ProductType;

class KeyCRMMappingForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'kycrm_mapping_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['keycrm.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('keycrm.settings');

    /** @var EntityTypeManagerInterface $entity_type_manager */
    $entity_type_manager = \Drupal::entityTypeManager();
    $renderer = \Drupal::service('renderer');

    // Отримати всі типи продуктів
    $product_types = ProductType::loadMultiple();

    foreach ($product_types as $bundle_id => $product_type) {
      echo "<h2>Тип продукту: {$product_type->label()} ({$bundle_id})</h2>";

      // Отримати перший продукт цього типу
      $products = $entity_type_manager
        ->getStorage('commerce_product')
        ->loadByProperties(['type' => $bundle_id]);

      /** @var \Drupal\commerce_product\Entity\ProductInterface|null $product */
      $product = reset($products);

      if (!$product) {
        echo "<em>Немає продуктів типу {$bundle_id}.</em><br>";
        continue;
      }

      // Перебрати лише title + кастомні поля (field_*)
      foreach ($product->getFields() as $field_name => $field) {
        if ($field_name !== 'title' && strpos($field_name, 'field_') !== 0) {
          continue;
        }

        // Якщо поле є посиланням на media-entity типу image
        if (
          $field->getFieldDefinition()->getType() === 'entity_reference' &&
          $field->getFieldDefinition()->getSetting('target_type') === 'media'
        ) {
          foreach ($field->referencedEntities() as $media) {
            if (
              $media instanceof Media &&
              $media->bundle() === 'image' &&
              $media->hasField('field_media_image') &&
              !$media->get('field_media_image')->isEmpty()
            ) {
              $image_file = $media->get('field_media_image')->entity;
              if ($image_file instanceof File) {
                $image_url = file_create_url($image_file->getFileUri());
                echo "<strong>$field_name (image)</strong>: <br><img src=\"$image_url\" style=\"max-width: 200px; height: auto;\"><br>";
                continue 2; // перейти до наступного поля
              }
            }
          }
        }

        // Якщо звичайне поле — рендерити як є
        if (!$field->isEmpty()) {
          $render_array = $field->view();
          $rendered_output = $renderer->renderPlain($render_array);
          echo "<strong>$field_name</strong>: $rendered_output<br>";
        }
      }

      echo "<hr>";
    }



  }





  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {}

}
